@@ -38,6 +38,9 @@ pub enum Value {
     #[tag("SpaceValues")]
     Space(SpaceValues),
 
+    #[tag("CommaValues")]
+    Comma(CommaValues),
+
     #[tag("BraceValue")]
     Brace(BraceValue),
 
@@ -59,6 +62,14 @@ pub struct SpaceValues {
     pub values: Vec<Value>,
 }
 
+/// List of values separated by a space.
+#[ast_node("CommaValues")]
+#[derive(Default)]
+pub struct CommaValues {
+    pub span: Span,
+    pub values: Vec<Value>,
+}
+
 #[ast_node("BinValue")]
 pub struct BinValue {
     pub span: Span,
